"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _types_1 = require("../@types");
const _constants_1 = require("../constants");
const comments_1 = require("../utilities/comments");
const rules_1 = require("../utilities/rules");
const rules_combined_1 = require("./rules-combined");
const rules_override_1 = require("./rules-override");
exports.parseRules = (css, options) => {
    const appends = [];
    let ignoreMode = _constants_1.IGNORE_MODE.DISABLED;
    css.each((node) => {
        if (node.type !== _constants_1.COMMENT_TYPE && node.type !== _constants_1.RULE_TYPE)
            return;
        if (node.type === _constants_1.COMMENT_TYPE) {
            const comment = node;
            const ignore = comments_1.getIgnoreComment(comment);
            if (ignore) {
                comment.remove();
                switch (ignore) {
                    case _constants_1.IGNORE_BEGIN:
                        ignoreMode = _constants_1.IGNORE_MODE.BLOCK_MODE;
                        break;
                    case _constants_1.IGNORE_END:
                        ignoreMode = _constants_1.IGNORE_MODE.DISABLED;
                        break;
                    default:
                        ignoreMode = _constants_1.IGNORE_MODE.NEXT_RULE;
                        break;
                }
                return;
            }
        }
        if (node.type === _constants_1.RULE_TYPE) {
            rules_1.parseRule(node);
            if (ignoreMode === _constants_1.IGNORE_MODE.NEXT_RULE) {
                ignoreMode = _constants_1.IGNORE_MODE.DISABLED;
                comments_1.removeRTLComments(node);
                return;
            }
            if (ignoreMode === _constants_1.IGNORE_MODE.BLOCK_MODE) {
                comments_1.removeRTLComments(node);
                return;
            }
            const rule = node;
            if (options.mode === _types_1.Mode.override) {
                rules_override_1.insertOverrideRules(appends, rule, options);
            }
            if (options.mode == _types_1.Mode.combined) {
                rules_combined_1.insertCombinedRules(appends, rule, options);
            }
        }
    });
    return appends;
};
