"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const postcss_1 = __importDefault(require("postcss"));
const rtlcss_1 = __importDefault(require("rtlcss"));
const _types_1 = require("../@types");
const _constants_1 = require("../constants");
const comments_1 = require("../utilities/comments");
const selectors_1 = require("../utilities/selectors");
const options_1 = require("../utilities/options");
exports.insertCombinedRules = (appends, rule, options) => {
    const { ltrPrefix, rtlPrefix, source, processUrls, useCalc, stringMap } = options;
    const ruleStr = rule.toString();
    const ruleFlippedtring = rtlcss_1.default.process(ruleStr, {
        clean: false,
        processUrls,
        useCalc,
        stringMap: options_1.getRTLCSSStringMap(stringMap)
    });
    if (ruleStr === ruleFlippedtring) {
        comments_1.removeRTLComments(rule);
        return;
    }
    const root = postcss_1.default.parse(ruleFlippedtring);
    const ruleFlipped = root.first;
    const deleteDeclarations = [];
    const ruleFlippedSecond = ruleFlipped.clone();
    let index = 0;
    ruleFlipped.walk((nodeFlipped) => {
        if (nodeFlipped.type === _constants_1.DECLARATION_TYPE) {
            const decl = rule.nodes[index];
            const declStr = decl.toString();
            const declFlippedStr = nodeFlipped.toString();
            const nodeFlippedSecond = ruleFlippedSecond.nodes[index];
            if (declStr === declFlippedStr) {
                deleteDeclarations.push(nodeFlipped);
                deleteDeclarations.push(nodeFlippedSecond);
            }
            else {
                nodeFlipped.replaceWith(decl.clone());
                deleteDeclarations.push(decl);
            }
        }
        index++;
    });
    deleteDeclarations.forEach((decl) => {
        const prev = decl.prev();
        if (prev && prev.type === _constants_1.COMMENT_TYPE) {
            prev.remove();
        }
        decl.remove();
    });
    selectors_1.addSelectorPrefixes(ruleFlipped, source === _types_1.Source.ltr ? ltrPrefix : rtlPrefix);
    selectors_1.addSelectorPrefixes(ruleFlippedSecond, source === _types_1.Source.rtl ? ltrPrefix : rtlPrefix);
    comments_1.removeRTLComments(rule);
    comments_1.removeRTLComments(ruleFlipped);
    comments_1.removeRTLComments(ruleFlippedSecond);
    appends.push({
        rule,
        ruleLTR: ruleFlipped,
        ruleRTL: ruleFlippedSecond
    });
};
