"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const postcss_1 = __importDefault(require("postcss"));
const rtlcss_1 = __importDefault(require("rtlcss"));
const _types_1 = require("../@types");
const _constants_1 = require("../constants");
const comments_1 = require("../utilities/comments");
const selectors_1 = require("../utilities/selectors");
const options_1 = require("../utilities/options");
exports.insertOverrideRules = (appends, rule, options) => {
    const { ltrPrefix, rtlPrefix, source, processUrls, useCalc, stringMap } = options;
    const prefixes = source === _types_1.Source.ltr ? rtlPrefix : ltrPrefix;
    const ruleStr = rule.toString();
    const ruleFlippedtring = rtlcss_1.default.process(ruleStr, {
        clean: false,
        processUrls,
        useCalc,
        stringMap: options_1.getRTLCSSStringMap(stringMap)
    });
    if (ruleStr === ruleFlippedtring) {
        comments_1.removeRTLComments(rule);
        return;
    }
    const root = postcss_1.default.parse(ruleFlippedtring);
    const ruleFlipped = root.first;
    let index = 0;
    ruleFlipped.walk((nodeFlipped) => {
        if (nodeFlipped.type === _constants_1.DECLARATION_TYPE) {
            const decl = rule.nodes[index];
            const declStr = decl.toString();
            const declFlippedStr = nodeFlipped.toString();
            if (declStr === declFlippedStr) {
                const prev = nodeFlipped.prev();
                if (prev && prev.type === _constants_1.COMMENT_TYPE) {
                    prev.remove();
                }
                nodeFlipped.remove();
            }
            else if (_constants_1.FLIP_PROPERTY_REGEXP.test(decl.prop.toString())) {
                const declClone = decl.clone();
                declClone.value = 'unset';
                nodeFlipped.before(declClone);
            }
        }
        index++;
    });
    selectors_1.addSelectorPrefixes(ruleFlipped, prefixes);
    comments_1.removeRTLComments(rule);
    comments_1.removeRTLComments(ruleFlipped);
    appends.push({
        rule,
        ruleLTR: source === _types_1.Source.ltr ? null : ruleFlipped,
        ruleRTL: source === _types_1.Source.rtl ? null : ruleFlipped
    });
};
