"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _types_1 = require("../@types");
const _constants_1 = require("../constants");
const defaultOptions = {
    mode: _types_1.Mode.combined,
    ltrPrefix: '[dir="ltr"]',
    rtlPrefix: '[dir="rtl"]',
    source: _types_1.Source.ltr,
    processUrls: false,
    useCalc: false,
    stringMap: [
        {
            search: ['left', 'Left', 'LEFT'],
            replace: ['right', 'Right', 'RIGHT']
        },
        {
            search: ['ltr', 'Ltr', 'LTR'],
            replace: ['rtl', 'Rtl', 'RTL'],
        }
    ]
};
const ModeValuesArray = Object.keys(_types_1.Mode).map((prop) => _types_1.Mode[prop]);
const SourceValuesArray = Object.keys(_types_1.Source).map((prop) => _types_1.Source[prop]);
const isNotAcceptedPrefix = (prefix) => {
    if (typeof prefix !== 'string' && !Array.isArray(prefix)) {
        return true;
    }
    if (Array.isArray(prefix)) {
        return prefix.some((item) => typeof item !== 'string');
    }
    return false;
};
const isNotAcceptedStringMap = (stringMap) => {
    if (!Array.isArray(stringMap)) {
        return true;
    }
    return stringMap.some((map) => isNotAcceptedPrefix(map.search) || isNotAcceptedPrefix(map.replace));
};
exports.parseOptions = (options) => {
    const returnOptions = { ...defaultOptions };
    if (options.mode && ModeValuesArray.includes(options.mode)) {
        returnOptions.mode = options.mode;
    }
    if (options.source && SourceValuesArray.includes(options.source)) {
        returnOptions.source = options.source;
    }
    if (!isNotAcceptedPrefix(options.ltrPrefix)) {
        returnOptions.ltrPrefix = options.ltrPrefix;
    }
    if (!isNotAcceptedPrefix(options.rtlPrefix)) {
        returnOptions.rtlPrefix = options.rtlPrefix;
    }
    if (typeof options.processUrls === _constants_1.BOOLEAN_TYPE) {
        returnOptions.processUrls = options.processUrls;
    }
    if (typeof options.useCalc === _constants_1.BOOLEAN_TYPE) {
        returnOptions.useCalc = options.useCalc;
    }
    if (!isNotAcceptedStringMap(options.stringMap)) {
        returnOptions.stringMap = options.stringMap;
    }
    return returnOptions;
};
const getStringMapName = (map) => {
    const search = Array.isArray(map.search) ? map.search[0] : map.search;
    const replace = Array.isArray(map.replace) ? map.replace[0] : map.replace;
    const reg = /[^\w]/g;
    const searchName = search.replace(reg, '-');
    const replaceName = replace.replace(reg, '_');
    return `${searchName}-${replaceName}`;
};
exports.getRTLCSSStringMap = (stringMap) => stringMap.map((map) => ({
    name: getStringMapName(map),
    priority: 100,
    search: map.search,
    replace: map.replace,
    options: {
        scope: '*',
        ignoreCase: false
    }
}));
